import os
import json
import requests
from mcp.server.fastmcp import FastMCP
from mcp_server_qiwei.core import QweiClient
from mcp_server_qiwei.app_config import AppConfig

mcp = FastMCP("mcp-qiwei")
client = QweiClient()

@mcp.tool()
def send_qiwei_message(msg: str) -> dict:
    """发送信息到企业微信群
    Args:
        msg: 推送的企业微信的信息，Markdown 格式（必填）
    Returns: <str> 
    """
    data = {
        "msg": msg,
    }
    return client.send_message(data)

def main():
    mcp.run()

if __name__ == "__main__":
    mcp.run()


import os
import requests
import json
from typing import Dict, Any, Optional
from base64 import b64encode
from mcp_server_qiwei.app_config import AppConfig

class QweiClient:
    def __init__(self):
        """
        使用配置文件中的常量进行初始化
        """
        config = AppConfig()
        self.bot_url = config.bot_url

    def send_message(self, data: Dict[str, Any]):
        chat_data = {
            'msgtype': 'markdown',
            'markdown': {
                'content': data['msg']
            }
        }
        headers = {'Content-Type': 'application/json'}
        response = requests.post(
            url=self.bot_url,
            headers=headers,
            json=chat_data,
            timeout=500
        )
        
        return response.text
   